Cell Maps Hierarchy Evaluation
================================================================


.. image:: https://img.shields.io/pypi/v/cellmaps_hierarchyeval.svg
        :target: https://pypi.python.org/pypi/cellmaps_hierarchyeval

.. image:: https://app.travis-ci.com/idekerlab/cellmaps_hierarchyeval.svg?branch=main
        :target: https://app.travis-ci.com/idekerlab/cellmaps_hierarchyeval



The Cell Maps Hierarchy Evaluation annotates a hierarchy created by `Cell Maps Generate Hierarchy`_
by performing enrichment against three NDEx_ networks HPA_, CORUM_, and GO-CC_

* Free software: MIT license
* Source code: https://github.com/idekerlab/cellmaps_hierarchyeval

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   usage
   inputs
   outputs
   modules
   developer
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _NDEx: https://www.ndexbio.org
.. _Cell Maps Generate Hierarchy: https://cellmaps-generate-hierarchy.readthedocs.io
.. _HPA: https://www.ndexbio.org/viewer/networks/a6a88e2d-9c0f-11ed-9a1f-005056ae23aa
.. _CORUM: https://www.ndexbio.org/viewer/networks/764f7471-9b79-11ed-9a1f-005056ae23aa
.. _GO-CC: https://www.ndexbio.org/viewer/networks/f484e8ee-0b0f-11ee-aa50-005056ae23aa
